/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's Federal        *
* education report file and create a SAS dataset.                                        *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\ussc_education_public.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = ussc_education_public ;

DATA library.&dataset ;
INFILE datafile LRECL=165;
INPUT
   USSCIDN  1-8             SENSPCAP  9-16           AGE  17-19            
   MONSEX  20-22            NEWCIT  23-25            NEWCNVTN  26-28       
   NEWRACE  29-31           OFFGUIDE  32-34          SENTIMP  35-37        
   SENTRNGE  38-40          SOURCES  41-43           TOTCHPTS  44-46       
   XCRHISSR  47-49          GLMIN  50-53             ED23_MD  54-56        
   ED23_DOC  57-59          ED23_NURSING  60-62      ED23_JD  63-65        
   ED23_COUNTRY  66-69      ED23_USDEGREE  70-72     ED23_MASTERS  73-75   
   ED23_PHD  76-78          ED23_PHARMD  79-81       ED23_DMD  82-84       
   ED23_DC  85-87           ED23_DVM  88-90          ED23_BA  91-93        
   ED23_ACCTG  94-96        ED23_PHARMACY  97-99     ED23_MEDICINE  100-102
   ED23_NATSCI  103-105     ED23_SOCSCI  106-108     ED23_REALESTATE  109-111
   ED23_OTHERBUS  112-114   ED23_EDUCATION  115-117   ED23_ENGINEERING  118-120
   ED23_COMPTECH  121-123   ED23_HEALTHADMIN  124-126
   ED23_OTHERHEALTH  127-129   ED23_CHIROPRACTIC  130-132
   ED23_RELIGIOUS  133-135   ED23_INTERNAT  136-138   ED23_DENTIST  139-141 
   ED23_SWCOUNSEL  142-144   ED23_ABUSE  145-147      ED23_LAW  148-150     
   ED23_EDUCCOMB  151-153   ECON_OFF_TYPE  154-161   ED23_FY  162-165      
 ;                       

LENGTH
   USSCIDN 6                AGE 3                    MONSEX 3              
   NEWCIT 3                 NEWCNVTN 3               NEWRACE 3             
   OFFGUIDE 3               SENTIMP 3                SENTRNGE 3            
   SOURCES 3                TOTCHPTS 3               XCRHISSR 3            
   GLMIN 4                  ED23_MD 3                ED23_DOC 3            
   ED23_NURSING 3           ED23_JD 3                ED23_COUNTRY 4        
   ED23_USDEGREE 3          ED23_MASTERS 3           ED23_PHD 3            
   ED23_PHARMD 3            ED23_DMD 3               ED23_DC 3             
   ED23_DVM 3               ED23_BA 3                ED23_ACCTG 3          
   ED23_PHARMACY 3          ED23_MEDICINE 3          ED23_NATSCI 3         
   ED23_SOCSCI 3            ED23_REALESTATE 3        ED23_OTHERBUS 3       
   ED23_EDUCATION 3         ED23_ENGINEERING 3       ED23_COMPTECH 3       
   ED23_HEALTHADMIN 3       ED23_OTHERHEALTH 3       ED23_CHIROPRACTIC 3   
   ED23_RELIGIOUS 3         ED23_INTERNAT 3          ED23_DENTIST 3        
   ED23_SWCOUNSEL 3         ED23_ABUSE 3             ED23_LAW 3            
   ED23_EDUCCOMB 3          ECON_OFF_TYPE 3          ED23_FY 4 ;

         

RUN ;
